#!/bin/bash

##
# Licensed Materials - Property of IBM
#
# IBM Insights Foundation for Energy  5725-W39
#
# (C) Copyright IBM Corp. 2015, 2016  All rights reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
## 

SOURCE="${BASH_SOURCE[0]}"
DIR="$( dirname "$SOURCE" )"

cd $DIR/..
export AOMS_ENV_ROOT="$PWD"

function usage() {
	echo "Usage: $0 [-n] [-c cfg file]"
	echo "-n skips Asset Health calculation"
}

CFG_FILE=$AOMS_ENV_ROOT/scripts/grid_engine.cfg
noaha=false
while getopts 'c:n' OPTION
do
  case $OPTION in
  c)	CFG_FILE="$OPTARG";;
  n)    noaha=true;;
  ?)	usage
  		exit 1;;
  esac
done
shift $(($OPTIND - 1))

function main() {
	if [ ! -f $CFG_FILE ]
	then
	    echo "Error: the configuration file $CFG_FILE does not exist, please specify the correct configuration file!"
	    exit 1 #exit the sript
	fi
	
	PROPERTIES_FILE=$CFG_FILE
	source $AOMS_ENV_ROOT/scripts/property.inc
	
	#Service config
	source_property serviceUrl
	source_property username
	password=$($AOMS_ENV_ROOT/scripts/utils/password.sh -d $PROPERTIES_FILE password)
	if [ $? -ne 0 ]; then
		echo "Error: wrong encoded portal password"
		exit 1
	fi
	source_property assetClassCodeList
	
	#DB config
	source_property dbuser
	dbpasswd=$($AOMS_ENV_ROOT/scripts/utils/password.sh -d $PROPERTIES_FILE dbpasswd)
	if [ $? -ne 0 ]; then
		echo "Error: wrong encoded database password"
		exit 1
	fi
	source_property dsname
	source_property DB2_DIR
	
	#Impact data
	source_property ImpactAssetClassCode
	source_property ImpactPropertyCode
	source_property CustomerGrowthFactor
	source_property ah_script_path

	if [ "$noaha" = false ] ; then
		#clean existing asset health scores
		#su - $dbuser -c "cd $ah_script_path/script; ./cleanScore.sh $dbuser $dbpasswd > $ah_script_path/log/cleanScore.log " 
		
		#call asset health scoring
		/bin/sh $ah_script_path/script/run_spss.sh $ah_script_path/script/modelerServer.cfg $ah_script_path/script/streamParams.cfg $ah_script_path/script/stream_assetHealth.cfg
		
		if [ $? -ne 0 ]; then
			echo "Error: Failed to call asset health scoring"
			exit 1
		fi
        echo "Successfully run asset health scoring"
	fi

	export PATH=$AOMS_ENV_ROOT/bin:$PATH
	source $AOMS_ENV_ROOT/scripts/aomsprofile.sh 
	
	cd $AOMS_ENV_ROOT/src/aoms-cfp
	source aoms-make-setupenv $PWD --force
	
	# The env var DB2_DIR should be defined 
	source $DB2_DIR/sqllib/db2profile
	source aoms-builder-setbase
	export AOMS_DB2_SCHEMA=CIM
	
	CFP_ARGS="--db $dsname:$dbuser:$dbpasswd --outputpath ${ah_script_path}/score --batchsize 1000 --impactcode $ImpactAssetClassCode --impactproperty $ImpactPropertyCode --customergrowthfactor $CustomerGrowthFactor $USER_CFP_ARGS"
	if [ -z "$DEBUGGER" ] ; then
	    $AOMS_BASE/../aoms-cfp/src/C/Progs/aoms_cfp/@_@g++64_CFP_t3 $CFP_ARGS 
	else
	    eval $AOMS_BASE/../aoms-cfp/src/C/Progs/aoms_cfp/@_@g++64_CFP_t3 $CFP_ARGS 
	fi
	
	if [ $? = 0 ] ; then
	
		#network risk score merge and persistence
		/bin/sh $ah_script_path/script/run_spss.sh $ah_script_path/script/modelerServer.cfg $ah_script_path/script/streamParams.cfg $ah_script_path/script/stream_merge_nra.cfg
	
        if [ $? = 0 ] ; then
            echo "Successfully run ah_cfp final score"
        else
            echo "Failed to run ah_cfp final score"
            exit 1
        fi

		if [ "$noaha" = false ] ; then
			echo "Info: calculate the scores for all containers"
			# call service to calculate the scores for the region containers
		curl -s -k -u $username:$password -X POST -H 'Content-Type: application/json' $serviceUrl/containerScore -d '[]'			

		fi	
		echo " "
		echo "##################################################################"
		echo "Successfully run cfp program"
		echo "##################################################################"
		echo " "		
	else
		echo " "	
		echo "##################################################################"
		echo "Failed to run cfp program, please refer to the previous messages"
		echo "for the detail errors"
		echo "##################################################################"
		echo " "	
	fi
	
	#clean existing Pole network risk scores
	#su - $dbuser -c "cd $ah_script_path/script; ./cleanPoleAssetScore.sh $dbuser $dbpasswd > $ah_script_path/log/cleanPoleAssetScore.log " 
		
	#call Pole network risk analysis
	/bin/sh $ah_script_path/script/run_spss.sh $ah_script_path/script/modelerServer.cfg $ah_script_path/script/streamParams.cfg $ah_script_path/script/stream_nra_pole.cfg
	if [ $? -ne 0 ]; then
		echo "Error: Failed to call network risk for pole "
		exit 1
	fi
    echo "Successfully run network risk scoring"
	
}

TIMESTMAP=`date +%Y%m%dT%H-%M-%S`
LOG_DIR=$AOMS_ENV_ROOT/scripts/logs
mkdir -p $LOG_DIR
LOG_FILE=$LOG_DIR/run_cfp_${TIMESTMAP}.log
ln -fs $LOG_FILE $LOG_DIR/run_cfp_LATEST.log

main 2>&1 | tee $LOG_FILE